Quickstart — django_dicom 0.1.0 documentation

# Quickstart

> - Add django_dicom to the INSTALLED_APPS setting in your Django project’s settings.py file:

>       INSTALLED_APPS = [
>           ...
>           'django_dicom',
>       ]

> - Include django_dicom’s URLs in your project by adding the following line to the urls.py file:

>       urlpatterns = [
>           ...
>           path('dicom/', include('django_dicom.urls')),
>       ]

> - Create the database tables:

>       python manage.py makemigrations django_dicom
>       python manage.py migrate django_dicom

> Warning

> django_dicom can only integrate with a PostgreSQL database. In order to set-up your project with PostgreSQL, try following this DjangoGirls tutorial.

> - Start the development server and visit http://127.0.0.1:8000/admin/ or http://127.0.0.1:8000/dicom/.